'use client'

import { createContext, useContext, useState, useEffect } from 'react'

type ThemeContextType = {
  isDark: boolean
  toggleTheme: () => void
  isLoading: boolean
}

const ThemeContext = createContext<ThemeContextType>({
  isDark: false,
  toggleTheme: () => {},
  isLoading: true
})

export function ThemeProvider({ children }: { children: React.ReactNode }) {
  const [isDark, setIsDark] = useState(false)
  const [isLoading, setIsLoading] = useState(true)

  useEffect(() => {
    // Client-side'da çalışacak kod
    const initializeTheme = () => {
      try {
        const systemPrefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches
        const savedTheme = localStorage.getItem('theme')
        
        if (!savedTheme) {
          setIsDark(systemPrefersDark)
          document.documentElement.classList.toggle('dark', systemPrefersDark)
          localStorage.setItem('theme', systemPrefersDark ? 'dark' : 'light')
        } else {
          const isDarkTheme = savedTheme === 'dark'
          setIsDark(isDarkTheme)
          document.documentElement.classList.toggle('dark', isDarkTheme)
        }
      } finally {
        setIsLoading(false)
      }
    }

    initializeTheme()
  }, [])

  const toggleTheme = () => {
    setIsDark((prev) => {
      const newTheme = !prev
      localStorage.setItem('theme', newTheme ? 'dark' : 'light')
      document.documentElement.classList.toggle('dark', newTheme)
      return newTheme
    })
  }

  // Loading durumunda boş bir div döndür
  if (isLoading) {
    return <>{children}</>
  }

  return (
    <ThemeContext.Provider value={{ isDark, toggleTheme, isLoading }}>
      {children}
    </ThemeContext.Provider>
  )
}

// Custom hook'u dışa aktar
export const useTheme = () => {
  const context = useContext(ThemeContext)
  if (context === undefined) {
    throw new Error('useTheme must be used within a ThemeProvider')
  }
  return context
} 